@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -28,20 +28,33 @@
 #ifndef _MAV_LWO_INCLUDE
 #define _MAV_LWO_INCLUDE
 
+#ifdef MAVAPI
+#undef MAVAPI
+#endif
+#if defined(WIN32) && !defined(__CYGWIN__) 
+#ifdef LIBMAV_LWO_EXPORTS
+#define MAVAPI __declspec(dllexport) 
+#else
+#define MAVAPI __declspec(dllimport) 
+#endif
+#else
+#define MAVAPI
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /* Routine to define a composite from a LWO file */
 
-int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix m);
+MAVAPI int mav_compositeReadLWO(char *filename, MAV_composite *c, MAV_matrix m);
 
 
 
 /* Module initialise */
 
-char *mav_LWOModuleID(void);
-int mav_LWOModuleInit(void);
+MAVAPI char *mav_LWOModuleID(void);
+MAVAPI int mav_LWOModuleInit(void);
 
 #ifdef __cplusplus
 }
