@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -28,14 +28,27 @@
 #ifndef _MAV_TR_INCLUDE
 #define _MAV_TR_INCLUDE
 
+#ifdef MAVAPI
+#undef MAVAPI
+#endif
+#if defined(WIN32) && !defined(__CYGWIN__) 
+#ifdef LIBMAV_TR_EXPORTS
+#define MAVAPI __declspec(dllexport) 
+#else
+#define MAVAPI __declspec(dllimport) 
+#endif
+#else
+#define MAVAPI
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 /* Module initialise */
 
-char *mav_TRModuleID(void);
-int mav_TRModuleInit(void);
+MAVAPI char *mav_TRModuleID(void);
+MAVAPI int mav_TRModuleInit(void);
 
 #ifdef __cplusplus
 }
