@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -147,15 +147,21 @@ MAV_BB old_bb;
   /* store its new surface area */
   mavlib_HBBCalculateSurfaceArea (&(node->box), &(node->surface_area));
 
-  /* if the size of the bound has changed, visit parent */
+  /* if the size of the bound has changed, update pos/size and visit parent */
   if ((node->box.min.x != old_bb.min.x) ||
       (node->box.min.y != old_bb.min.y) ||
       (node->box.min.z != old_bb.min.z) ||
       (node->box.max.x != old_bb.max.x) ||
       (node->box.max.y != old_bb.max.y) ||
-      (node->box.max.z != old_bb.max.z))
+      (node->box.max.z != old_bb.max.z)) {
+    node->pos= mav_vectorAdd (mav_vectorScalar (node->box.min, 0.5),
+		mav_vectorScalar (node->box.max, 0.5));
+    node->size= mav_vectorDotProduct (
+		mav_vectorSub (node->box.max, node->box.min),
+		mav_vectorSub (node->box.max, node->box.min));
     if (node->parent != NULL)
       mavlib_HBBRecalculateNodeBound (node->parent);
+  }
 }
 
 void mavlib_HBBInsertObjectAsNode (MAV_HBBCluster *node, MAV_object *obj, MAV_BB *bb) {
@@ -169,6 +175,10 @@ void mavlib_HBBInsertObjectAsNode (MAV_HBBCluster *node, MAV_object *obj, MAV_BB
 
   mavlib_HBBCalculateSurfaceArea (bb, &(new_cluster->surface_area));
   new_cluster->box= *bb;
+  new_cluster->pos= mav_vectorAdd (mav_vectorScalar (bb->min, 0.5),
+		mav_vectorScalar (bb->max, 0.5));
+  new_cluster->size= mav_vectorDotProduct (mav_vectorSub (bb->max, bb->min),
+		mav_vectorSub (bb->max, bb->min));
   new_cluster->obj= obj;
   new_cluster->num_children= 0;
   new_cluster->children= NULL;
@@ -201,12 +211,18 @@ void mavlib_HBBInsertObjectAsLeaf (MAV_HBBCluster *node, MAV_object *obj, MAV_BB
 
   mavlib_HBBCalculateSurfaceArea (bb, &(cluster_right->surface_area));
   cluster_right->box= *bb;
+  cluster_right->pos= mav_vectorAdd (mav_vectorScalar (bb->min, 0.5),
+		mav_vectorScalar (bb->max, 0.5));
+  cluster_right->size= mav_vectorDotProduct (mav_vectorSub (bb->max, bb->min),
+		mav_vectorSub (bb->max, bb->min));
   cluster_right->obj= obj;
   cluster_right->num_children= 0;
   cluster_right->children= NULL;
   cluster_right->parent= node;
 
   cluster_left->box= node->box;
+  cluster_left->pos= node->pos;
+  cluster_left->size= node->size;
   cluster_left->obj= node->obj;
   /* left cluster has all children of original node */
   cluster_left->num_children= node->num_children;
@@ -297,6 +313,10 @@ int mav_HBBObjectAdd (MAV_SMS *sms, MAV_object *obj) {
   /* first object */
     hbb->root= (MAV_HBBCluster *) mav_malloc (sizeof (MAV_HBBCluster));
     hbb->root->box= bb;
+    hbb->root->pos= mav_vectorAdd (mav_vectorScalar (bb.min, 0.5),
+		mav_vectorScalar (bb.max, 0.5));
+    hbb->root->size= mav_vectorDotProduct (mav_vectorSub (bb.max, bb.min),
+		mav_vectorSub (bb.max, bb.min));
     mavlib_HBBCalculateSurfaceArea (&bb, &(hbb->root->surface_area));
     hbb->root->num_children= 0;
     hbb->root->obj= obj;
