@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -1492,6 +1492,7 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
     mavlib_win32EventInfo[6]=0;
     switch (wparam)
     {
+    case VK_DELETE: mavlib_win32EventInfo[6]= 127; break;
     case VK_F1: mavlib_win32EventInfo[6]= 300; break;
     case VK_F2: mavlib_win32EventInfo[6]= 301; break;
     case VK_F3: mavlib_win32EventInfo[6]= 302; break;
@@ -1510,7 +1511,7 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
     case VK_RIGHT: mavlib_win32EventInfo[6]= 315; break;
     case VK_PRIOR: mavlib_win32EventInfo[6]= 316; break;
     case VK_NEXT: mavlib_win32EventInfo[6]= 317; break;
-    case VK_SHIFT: ch= lparam >> 16;
+    case VK_SHIFT: ch= (char) (lparam >> 16);
 		   if (ch==MapVirtualKey (VK_SHIFT, 0))
 		     mavlib_win32EventInfo[6]= 318; /* left shift */
 		   else
