@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -63,26 +63,39 @@
 /* These are the only bits of Maverik we need. Keep interface to window
    manager as light as possible to make its easy for other implementation */
 
+#ifdef MAVAPI
+#undef MAVAPI
+#endif
+#if defined(WIN32) && !defined(__CYGWIN__) 
+#ifdef LIBMAVERIK_EXPORTS
+#define MAVAPI __declspec(dllexport) 
+#else
+#define MAVAPI __declspec(dllimport) 
+#endif
+#else
+#define MAVAPI
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
-void mav_gfxWindowOpen(int id, int x, int y, int w, int h, char *name, char *disp, int wmp, int sb, int qb, int ms, int ab, int stenb, int desta, int *wret, int *hret);
-void mav_gfxWindowClose(int id);
-void mav_gfxWindowSet(int id);
-void mav_gfxWindowBuffersSwap(void);
-void mav_gfxWindowResGet(int *x, int *y);
-int  mav_gfxWindowEventGet(int *info);
-int  mav_gfxWindowEventPeek(void);
-int  mav_gfxWindowPointerGet(int id, int *x, int *y, int *rx, int *ry, int *buts);
-void mav_gfxWindowPointerSet(int win, int x, int y);
-int  mav_gfxWindowKeyGet(int key);
-int  mav_gfxWindowFontSet(char *s, int font, int *width);
-void mav_gfxWindowStringDisplay(char *s, int font);
-void mav_moduleNew(char *fn(void));
-int  mav_gfxModuleInit(void);
-char *mav_gfxModuleID(void);
-void mav_gfx3DfxModeSet(int fullscreen);
-int  mav_gfx3DfxBoardSet(int bd);
+MAVAPI void mav_gfxWindowOpen(int id, int x, int y, int w, int h, char *name, char *disp, int wmp, int sb, int qb, int ms, int ab, int stenb, int desta, int *wret, int *hret);
+MAVAPI void mav_gfxWindowClose(int id);
+MAVAPI void mav_gfxWindowSet(int id);
+MAVAPI void mav_gfxWindowBuffersSwap(void);
+MAVAPI void mav_gfxWindowResGet(int *x, int *y);
+MAVAPI int  mav_gfxWindowEventGet(int *info);
+MAVAPI int  mav_gfxWindowEventPeek(void);
+MAVAPI int  mav_gfxWindowPointerGet(int id, int *x, int *y, int *rx, int *ry, int *buts);
+MAVAPI void mav_gfxWindowPointerSet(int win, int x, int y);
+MAVAPI int  mav_gfxWindowKeyGet(int key);
+MAVAPI int  mav_gfxWindowFontSet(char *s, int font, int *width);
+MAVAPI void mav_gfxWindowStringDisplay(char *s, int font);
+MAVAPI void mav_moduleNew(char *fn(void));
+MAVAPI int  mav_gfxModuleInit(void);
+MAVAPI char *mav_gfxModuleID(void);
+MAVAPI void mav_gfx3DfxModeSet(int fullscreen);
+MAVAPI int  mav_gfx3DfxBoardSet(int bd);
 #ifdef __cplusplus
 }
 #endif
@@ -657,6 +670,7 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
     /* Translate keycode into ASCII value or #defines */
     mavlib_win32EventInfo[6]=0;
     switch (wparam) {
+    case VK_DELETE: mavlib_win32EventInfo[6]= 127; break;
     case VK_F1: mavlib_win32EventInfo[6]= 300; break;
     case VK_F2: mavlib_win32EventInfo[6]= 301; break;
     case VK_F3: mavlib_win32EventInfo[6]= 302; break;
@@ -676,7 +690,7 @@ LONG WINAPI mavlib_winEventHandler(HWND hwnd, UINT umsg, WPARAM wparam, LPARAM l
     case VK_PRIOR: mavlib_win32EventInfo[6]= 316; break;
     case VK_NEXT: mavlib_win32EventInfo[6]= 317; break;
     case VK_SHIFT:
-	ch= (char) lparam >> 16;
+	ch= (char) (lparam >> 16);
 	if (ch==(char) MapVirtualKey (VK_SHIFT, 0))
 	  mavlib_win32EventInfo[6]= 318; /* left shift */
 	else
