@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -228,11 +228,6 @@ int mav_gfxModuleInit()
   /* Open connection to display */  
   mavlib_XOpen(0, NULL);
 
-#ifndef MAV_SUNOS4
-  /* clean up on application exit */
-  atexit(mavlib_gfxExit);
-#endif
-
   /* use environment variable to look for a Voodoo card */
   voodoo= getenv("MESA_GLX_FX");
   if (voodoo) {
