@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -44,12 +44,12 @@ int gethostname(char *name, size_t len);
 #include <dlfcn.h>
 #endif
 
-const MAV_vector MAV_NULL_VECTOR={0,0,0};
-const MAV_vector MAV_X_VECTOR={1,0,0};
-const MAV_vector MAV_Y_VECTOR={0,1,0};
-const MAV_vector MAV_Z_VECTOR={0,0,1};
-const MAV_matrix MAV_ID_MATRIX={{{1,0,0,0},{0,1,0,0},{0,0,1,0},{0,0,0,1}}};
-const MAV_quaternion MAV_ID_QUATERNION={1,0,0,0};
+MAV_vector MAV_NULL_VECTOR={0,0,0};
+MAV_vector MAV_X_VECTOR={1,0,0};
+MAV_vector MAV_Y_VECTOR={0,1,0};
+MAV_vector MAV_Z_VECTOR={0,0,1};
+MAV_matrix MAV_ID_MATRIX={{{1,0,0,0},{0,1,0,0},{0,0,1,0},{0,0,0,1}}};
+MAV_quaternion MAV_ID_QUATERNION={1,0,0,0};
 
 MAV_window *mav_win_all;
 MAV_palette *mav_palette_default;
@@ -81,6 +81,7 @@ void *mavlib_dlh= NULL;
 int mav_opt_bindTextures= MAV_UNDEFINED;
 int mav_opt_shareContexts= MAV_UNDEFINED;
 int mav_opt_syncSwap= MAV_UNDEFINED;
+int mav_opt_defaultInit= MAV_TRUE;
 
 /* For passing options to modules. Need global vars to cope cleanly with */
 /* modules initialised from the application. */
@@ -93,7 +94,7 @@ FILE *mav_userconf= NULL;
 
 char *mav_kernelID(void)
 {
-  return "GNU Maverik v6.1";
+  return "GNU Maverik v6.2";
 }
 
 #if defined(WIN32) || defined(macintosh)
@@ -520,7 +521,7 @@ void mav_initialise(int *argc_p, char *argv[])
   mavlib_kernelOptionsDefaultSet();
   
   /* identify the kernel version */
-  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "%s - Copyright (C) 1999-2001 Advanced Interfaces Group\n", mav_kernelID());
+  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "%s - Copyright (C) 1999-2002 Advanced Interfaces Group\n", mav_kernelID());
 
   /* create kernel defined callbacks to delete an object and SMS and remove an object from an SMS */
   mav_callback_delete= mav_callbackNew();
@@ -633,10 +634,12 @@ void mav_initialise(int *argc_p, char *argv[])
 
   if (defaultInit) 
   {
-    i=0;
-    while (defaultMod[i]) {
-      mavlib_execInit(defaultMod[i]);
-      i++;
+    if (mav_opt_defaultInit) {
+      i=0;
+      while (defaultMod[i]) {
+	mavlib_execInit(defaultMod[i]);
+	i++;
+      }
     }
   }
   else
