@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -56,6 +56,14 @@ void srand48(long int seedval);
 #endif
 #endif
 
+#if defined(machintosh)
+#elif defined(WIN32) && !defined(__CYGWIN__)
+#include <process.h>
+#else
+#include <sys/types.h>
+#include <unistd.h>
+#endif
+
 int mav_opt_fixedRnd= MAV_FALSE;
 
 
@@ -273,6 +281,11 @@ MAV_matrix mav_matrixRPYSet(MAV_matrix m, float roll, float pitch, float yaw)
   MAV_matrix mat;
   float cosroll,sinroll,cospitch,sinpitch,cosyaw,sinyaw;
   float sinyawcosroll,sinyawsinroll;
+  float sc;
+
+/* Get scale */
+
+  sc= mav_matrixScaleGet(m);
 
 /* Convert to radians */
 
@@ -312,6 +325,10 @@ MAV_matrix mav_matrixRPYSet(MAV_matrix m, float roll, float pitch, float yaw)
   mat.mat[3][2] = 0.0;
   mat.mat[3][3] = 1.0;
 
+/* Preserve scale */
+
+  mav_matrixScaleSet(m, sc);
+
   return mat;
 }
 
@@ -1624,3 +1641,33 @@ void mav_randomSeed(long seed)
 #endif
   }
 }
+
+
+
+char *mav_getTempDir(void)
+{
+#if defined(__CYGWIN__)
+  return "/tmp/";
+#elif defined(WIN32)
+  return getenv("TEMP");
+#elif defined(macintosh)
+  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: guessing at temporary Mac directory\n");
+  return ".";
+#else
+  return "/tmp/";
+#endif  
+}
+
+int mav_getPID(void)
+{
+#if defined(__CYGWIN__)
+  return getpid();
+#elif defined(WIN32)
+  return _getpid();
+#elif defined(macintosh)
+  if (mav_opt_output==MAV_VERBOSE) fprintf(stderr, "Warning: guessing at Mac process PID\n");
+  return 1;
+#else
+  return getpid();
+#endif  
+}
