@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -517,8 +517,12 @@ int mavlib_readPPM(char *filename, int *width, int *height, unsigned long **mem)
 
   fscanf(file, "%i", &mv);
 
-  /* if binary, read since white space char */
-  if (bin) fscanf(file, "%c", &str[0]);
+  /* if binary, read until newline */
+  if (bin) {
+    do {
+      fscanf(file, "%c", &str[0]);
+    } while (str[0]!=10);
+  }
 
 /* Parse */
   
@@ -707,11 +711,11 @@ int mavlib_readPNG(char *filename, int *width, int *height, unsigned long **mem)
 
 
 
-/* Routine to define a texture in a given palette (from file) */
+/* Routines to define a texture in a given palette (from file) */
 
 #define L2 0.301029995
 
-int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
+int mavlib_paletteTextureSetSC(MAV_palette *p, int index, char *filename)
 {
   int width, height, rv= MAV_FALSE;
 
@@ -743,16 +747,16 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 #endif
     else
     {
-#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
+#if !defined(macintosh)
       char buf[500], f1[500], f2[500];
       int srv;
 
 #ifdef MAV_PNG
-      sprintf(f1, "/tmp/mavtex%i.png", getpid());
+      sprintf(f1, "%s/mavtex%i.png", mav_getTempDir(), mav_getPID());
 #else
-      sprintf(f1, "/tmp/mavtex%i.ppm", getpid());
+      sprintf(f1, "%s/mavtex%i.ppm", mav_getTempDir(), mav_getPID());
 #endif
-      sprintf(f2, "/tmp/mavtexlog%i", getpid());
+      sprintf(f2, "%s/mavtexlog%i", mav_getTempDir(), mav_getPID());
 
       sprintf(buf, "convert -matte %s %s 2>%s", filename, f1, f2);
       srv= system(buf);
@@ -766,8 +770,8 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 	rv= mavlib_readPPM(f1, &p->texlist[index].width, &p->texlist[index].height, &p->texlist[index].mem);
 #endif
 	if (rv != MAV_FALSE) {
-	  sprintf(buf, "rm -f %s %s", f1, f2);
-	  system(buf);
+	  unlink(f1);
+	  unlink(f2);
 	}
       }
       else
@@ -802,16 +806,16 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 	mav_free(p->texlist[index].mem);
 
 	{
-#if (!defined(WIN32) || defined(__CYGWIN__)) && !defined(macintosh)
+#if !defined(macintosh)
 	  char buf[500], f1[500], f2[500];
 	  int srv;
 
 #ifdef MAV_PNG
-	  sprintf(f1, "/tmp/mavtex%i.png", getpid());
+	  sprintf(f1, "%s/mavtex%i.png", mav_getTempDir(), mav_getPID());
 #else
-	  sprintf(f1, "/tmp/mavtex%i.ppm", getpid());
+	  sprintf(f1, "%s/mavtex%i.ppm", mav_getTempDir(), mav_getPID());
 #endif
-	  sprintf(f2, "/tmp/mavtexlog%i", getpid());
+	  sprintf(f2, "%s/mavtexlog%i", mav_getTempDir(), mav_getPID());
 
 	  sprintf(buf, "convert -matte -geometry %ix%i! %s %s 2>%s", tw, th, filename, f1, f2);
 
@@ -826,8 +830,8 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
 	    rv= mavlib_readPPM(f1, &p->texlist[index].width, &p->texlist[index].height, &p->texlist[index].mem);
 #endif
 	    if (rv != MAV_FALSE) {
-	      sprintf(buf, "rm -f %s %s", f1, f2);
-	      system(buf);
+	      unlink(f1);
+	      unlink(f2);
 	    }
 	  }
 	  else
@@ -855,11 +859,39 @@ int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
   return(rv);
 }
 
+int mav_paletteTextureSet(MAV_palette *p, int index, char *filename)
+{
+  int rv= MAV_TRUE;
+
+  if (mav_opt_shareContexts)
+  {
+    rv= mavlib_paletteTextureSetSC(p, index, filename);
+  }
+  else
+  {
+    MAV_window *orig= mav_win_current, *win;
+    int pw= mav_opt_paletteWarn;
+    mav_opt_paletteWarn= MAV_FALSE;
+
+    /* Set texture in each window */
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &win)) {
+      mav_windowSet(win);    
+      rv|= mavlib_paletteTextureSetSC(p, index, filename);
+    }
+
+    mav_windowSet(orig);    
+    mav_opt_paletteWarn= pw;
+  }
+  
+  return rv;
+}
 
 
-/* Routine to set the alpha component of a texture to a given value */
 
-void mav_paletteTextureAlphaSet(MAV_palette *p, int index, float a)
+/* Routines to set the alpha component of a texture to a given value */
+
+void mavlib_paletteTextureAlphaSetSC(MAV_palette *p, int index, float a)
 {
   MAV_texture *tex;
   int i, v;
@@ -910,11 +942,35 @@ void mav_paletteTextureAlphaSet(MAV_palette *p, int index, float a)
   }
 }
 
+void mav_paletteTextureAlphaSet(MAV_palette *p, int index, float a)
+{
+  if (mav_opt_shareContexts)
+  {
+    mavlib_paletteTextureAlphaSetSC(p, index, a);
+  }
+  else
+  {
+    MAV_window *orig= mav_win_current, *win;
+    int pw= mav_opt_paletteWarn;
+    mav_opt_paletteWarn= MAV_FALSE;
+
+    /* Set texture in each window */
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &win)) {
+      mav_windowSet(win);    
+      mavlib_paletteTextureAlphaSetSC(p, index, a);
+    }
+
+    mav_windowSet(orig);    
+    mav_opt_paletteWarn= pw;
+  }
+}
 
 
-/* Routine to set the alpha component of a texture whose pixels are coloured rgb */
 
-void mav_paletteTextureColourAlphaSet(MAV_palette *p, int index, int r, int g, int b, float a)
+/* Routines to set the alpha component of a texture whose pixels are coloured rgb */
+
+void mavlib_paletteTextureColourAlphaSetSC(MAV_palette *p, int index, int r, int g, int b, float a)
 {
   MAV_texture *tex;
   int i, v;
@@ -965,6 +1021,30 @@ void mav_paletteTextureColourAlphaSet(MAV_palette *p, int index, int r, int g, i
   }
 }
 
+void mav_paletteTextureColourAlphaSet(MAV_palette *p, int index, int r, int g, int b, float a)
+{
+  if (mav_opt_shareContexts)
+  {
+    mavlib_paletteTextureColourAlphaSetSC(p, index, r, g, b, a);
+  }
+  else
+  {
+    MAV_window *orig= mav_win_current, *win;
+    int pw= mav_opt_paletteWarn;
+    mav_opt_paletteWarn= MAV_FALSE;
+
+    /* Set texture in each window */
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &win)) {
+      mav_windowSet(win);
+      mavlib_paletteTextureColourAlphaSetSC(p, index, r, g, b, a);
+    }
+
+    mav_windowSet(orig);    
+    mav_opt_paletteWarn= pw;
+  }
+}
+
 
 
 /* Routine to define if a texture is mipmapped */
@@ -987,7 +1067,7 @@ void mav_paletteTextureMipmappingSet(MAV_palette *p, int index, int v)
 
 /* Routine to define a texture in a given palette (from mem) */
 
-int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, unsigned long *mem)
+int mavlib_paletteTextureSetFromMemSC(MAV_palette *p, int index, int width, int height, unsigned long *mem)
 {
   int rv= MAV_TRUE;
 
@@ -1029,6 +1109,34 @@ int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int heigh
   return rv;
 }
 
+int mav_paletteTextureSetFromMem(MAV_palette *p, int index, int width, int height, unsigned long *mem)
+{
+  int rv= MAV_TRUE;
+
+  if (mav_opt_shareContexts)
+  {
+    rv= mavlib_paletteTextureSetFromMemSC(p, index, width, height, mem);
+  }
+  else
+  {
+    MAV_window *orig= mav_win_current, *win;
+    int pw= mav_opt_paletteWarn;
+    mav_opt_paletteWarn= MAV_FALSE;
+
+    /* Set texture in each window */
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &win)) {
+      mav_windowSet(win);
+      rv|= mavlib_paletteTextureSetFromMemSC(p, index, width, height, mem);
+    }
+
+    mav_windowSet(orig);    
+    mav_opt_paletteWarn= pw;
+  }
+  
+  return rv;
+}
+
 
 
 /* Define texture environment */
@@ -1283,9 +1391,9 @@ int mav_surfaceParamsIsTextured(MAV_window *win, MAV_surfaceParams *sp)
 
 
 
-/* Routine to define a font */
+/* Routines to define a font */
 
-void mav_paletteFontSet(MAV_palette *p, int index, char *s)
+void mavlib_paletteFontSetSC(MAV_palette *p, int index, char *s)
 {
 /* Check index is within range */
 
@@ -1312,6 +1420,30 @@ void mav_paletteFontSet(MAV_palette *p, int index, char *s)
   }
 }
 
+void mav_paletteFontSet(MAV_palette *p, int index, char *s)
+{
+  if (mav_opt_shareContexts)
+  {
+    mavlib_paletteFontSetSC(p, index, s);
+  }
+  else
+  {
+    MAV_window *orig= mav_win_current, *win;
+    int pw= mav_opt_paletteWarn;
+    mav_opt_paletteWarn= MAV_FALSE;
+
+    /* Set font in each window */
+    mav_listPointerReset(mav_win_list);
+    while (mav_listItemNext(mav_win_list, (void **) &win)) {
+      mav_windowSet(win);    
+      mavlib_paletteFontSetSC(p, index, s);
+    }
+
+    mav_windowSet(orig);    
+    mav_opt_paletteWarn= pw;
+  }
+}
+
 
 
 /* Routines to return an empty index in the palette */
